@@ -110,7 +110,7 @@ _service_endpoints_template = {
 # TODO remove service port mapping above entirely
 if os.environ.get('USE_LEGACY_PORTS') not in ['1', 'true']:
     for key, value in _service_endpoints_template.items():
-        if key not in ['dashboard', 'elasticsearch']:
+        if key not in ['dashboard', 'elasticsearch', 'opensearch']:
             _service_endpoints_template[key] = '%s:%s' % (value.rpartition(':')[0], EDGE_PORT)
 
 
